<template>
  <j-modal
    :title="title"
    :width="width"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @cancel="handleCancel"
    :okButtonProps="{ style: { display: 'none' } }"
    cancelText="关闭">
    <a-card :bordered="false">
      <!-- 查询区域 -->
      <div class="table-page-search-wrapper">
        <a-form layout="inline" @keyup.enter.native="searchQuery">
          <a-row :gutter="24">
          </a-row>
        </a-form>
      </div>

      <!-- table区域-begin -->
      <div>
        <a-table
          ref="table"
          size="middle"
          :scroll="{x:true}"
          bordered
          rowKey="id"
          :columns="columns"
          :dataSource="dataSource"
          :pagination="ipagination"
          :loading="loading"
          :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
          class="j-table-force-nowrap"
          @change="handleTableChange">

          <template slot="htmlSlot" slot-scope="text">
            <div v-html="text"></div>
          </template>
          <template slot="imgSlot" slot-scope="text,record">
            <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
            <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt=""
                 style="max-width:80px;font-size: 12px;font-style: italic;" />
          </template>
          <template slot="fileSlot" slot-scope="text">
            <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
            <a-button
              v-else
              :ghost="true"
              type="primary"
              icon="download"
              size="small"
              @click="downloadFile(text)">
              下载
            </a-button>
          </template>

          <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

        </a-table>
      </div>

      <mes-material-transfer-detail-modal ref="modalForm" @ok="modalFormOk"></mes-material-transfer-detail-modal>
    </a-card>
  </j-modal>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import MesMaterialTransferDetailModal from './modules/MesMaterialTransferDetailModal'

export default {
  name: 'MesMaterialTransferDetailList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    MesMaterialTransferDetailModal
  },
  data() {
    return {
      description: '物料拉动明细管理页面',
      title: '物料拉动明细',
      width: 1000,
      toolsVisable: true,
      visible: false,
      confirmLoading: false,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        // {
        //   title: '删除标记',
        //   align: 'center',
        //   dataIndex: 'delFlag'
        // },
        // {
        //   title: '申请单ID',
        //   align: 'center',
        //   dataIndex: 'requestId'
        // },
        {
          title: '物料编码',
          align: 'center',
          dataIndex: 'materialNumber'
        },
        {
          title: '物料名称',
          align: 'center',
          dataIndex: 'materialName'
        },
        {
          title: '理论拉动数量',
          align: 'center',
          dataIndex: 'specifiedQuantity'
        },
        {
          title: '实际拉动数量',
          align: 'center',
          dataIndex: 'actualQuantity'
        },
        {
          title: '车间剩余数量',
          align: 'center',
          dataIndex: 'remainingQuantity'
        },
        // {
        //   title: '操作',
        //   dataIndex: 'action',
        //   align: 'center',
        //   fixed: 'right',
        //   width: 147,
        //   scopedSlots: { customRender: 'action' }
        // }
      ],
      url: {
        list: '/mes/mesMaterialTransferDetail/list',
        delete: '/mes/mesMaterialTransferDetail/delete',
        deleteBatch: '/mes/mesMaterialTransferDetail/deleteBatch',
        exportXlsUrl: '/mes/mesMaterialTransferDetail/exportXls',
        importExcelUrl: 'mes/mesMaterialTransferDetail/importExcel'

      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    handleCancel(){
      this.visible=false
      this.dataSource = []
    },
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'int', value: 'delFlag', text: '删除标记', dictCode: '' })
      fieldList.push({ type: 'string', value: 'requestId', text: '申请单ID', dictCode: '' })
      fieldList.push({ type: 'string', value: 'materialNumber', text: '物料编码', dictCode: '' })
      fieldList.push({ type: 'string', value: 'materialName', text: '物料名称', dictCode: '' })
      fieldList.push({ type: 'double', value: 'specifiedQuantity', text: '理论拉动数量', dictCode: '' })
      fieldList.push({ type: 'double', value: 'actualQuantity', text: '实际拉动数量', dictCode: '' })
      fieldList.push({ type: 'double', value: 'remainingQuantity', text: '车间剩余数量', dictCode: '' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>